Module functional

Module functional 

Functional APIs for preprocessing

This module provides functional APIs that directly transform data without needing to create and fit transformer objects.

Functions

add_dummy_feature
Add a dummy feature to the data
binarize
Boolean thresholding of array-like or scipy.sparse matrix
label_binarize
Binarize labels in a one-vs-all fashion
maxabs_scale
Scale each feature by its maximum absolute value
minmax_scale
Transform features to range [0, 1]
normalize
Scale samples individually to unit norm
robust_scale
Scale features using statistics that are robust to outliers
scale
Standardize a dataset along any axis